﻿using System;
using System.Diagnostics;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;


public class SignDocuments
{

    private static string key = "api_key";
    private static string url = "https://sandbox.esignlive.com/api";

    public static void Main(string[] args) {

        EslClient client = new EslClient(key, url);

        //Package
        PackageBuilder packageToBuild = PackageBuilder.NewPackageNamed("Sign Documents Test");

        //Sender
        SignerBuilder signer1 = SignerBuilder.NewSignerWithEmail("sender@example.com")
                .WithFirstName("Haris")
                .WithLastName("Haidary")
                .WithCustomId("Sender");
        //Client
        SignerBuilder signer2 = SignerBuilder.NewSignerWithEmail("client@example.com")
                .WithFirstName("John")
                .WithLastName("Smith")
                .WithCustomId("Signer");

        //Signatures
        SignatureBuilder signature1 = SignatureBuilder.SignatureFor("sender@example.com")
                .WithPositionAnchor(TextAnchorBuilder.NewTextAnchor("Signature of the Contractor")
                        .AtPosition(TextAnchorPosition.TOPLEFT)
                        .WithSize(150, 40)
                        .WithOffset(0, -50)
                        .WithCharacter(0)
                        .WithOccurrence(0));

        SignatureBuilder signature2 = SignatureBuilder.SignatureFor("client@example.com")
                .WithPositionAnchor(TextAnchorBuilder.NewTextAnchor("Signature of the Client")
                        .AtPosition(TextAnchorPosition.TOPLEFT)
                        .WithSize(150, 40)
                        .WithOffset(0, -50)
                        .WithCharacter(0)
                        .WithOccurrence(0));


        //Document
        DocumentBuilder document1 = DocumentBuilder.NewDocumentNamed("Cleaning Contract")
                .FromFile("DOC_FILE_PATH")
                .WithSignature(signature1)
                .WithSignature(signature2);


        //Build package
        DocumentPackage packageToSend = packageToBuild.WithSigner(signer1).WithSigner(signer2).WithDocument(document1).Build();

        PackageId packageId = client.CreateAndSendPackage(packageToSend);

        client.SignDocuments(packageId);

	}

}

